#
# spec file for package mate-tweak
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   mate_tweak
Name:           mate-tweak
Version:        22.10.0
Release:        2.3
Summary:        MATE desktop tweak tool
License:        GPL-2.0-or-later
Group:          System/GUI/Other
URL:            https://github.com/ubuntu-mate/mate-tweak
Source:         %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE mate-tweak-use-matemenu.patch sor.alexei@meowr.ru -- Layouts are patched to use mate-menu instead of mintMenu or gnome-main-menu.
Patch0:         mate-tweak-use-matemenu.patch
BuildRequires:  Mesa-demo-x
BuildRequires:  dconf
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  python3
BuildRequires:  python3-configobj
BuildRequires:  python3-distutils-extra
BuildRequires:  python3-gobject
BuildRequires:  python3-psutil
BuildRequires:  python3-setproctitle
BuildRequires:  python3-setuptools
BuildRequires:  pkgconfig(gobject-introspection-1.0)
Requires:       Mesa-demo-x
Requires:       dconf
Requires:       mate-panel
Requires:       python3-base
Requires:       python3-configobj
Requires:       python3-distro
Requires:       python3-gobject
Requires:       python3-gobject-Gdk
Requires:       python3-psutil
Requires:       python3-setproctitle
Requires:       python3-setuptools
# For privilege granting.
Requires:       xdg-utils
Recommends:     mate-applet-indicator
Suggests:       mate-hud
BuildArch:      noarch

%description
Configures some aspects of the MATE desktop not exposed via the
MATE Control Centre applets.

Settings that can be handled via MATE Tweak:
 * Show/hide standard desktop icons.
 * Panel fine-tuning (icon visibility, in menus and on buttons,
   icon size, button labelling, contex menus, etc.).
 * Window manager fine-tuning.

%lang_package

%prep
%autosetup -p1
# Make world a bit simpler.
sed -i "s/'pkexec', '/'xdg-su', '-c /g" %{name}
sed -i '/polkit/d' setup.py

%build
%py3_build

%install
%py3_install

# Give gi-find-deps.sh a bait.
ln -s %{_bindir}/%{name} %{buildroot}%{_prefix}/lib/%{name}/%{name}.py

%if 0%{?suse_version} > 1500
rm %{buildroot}%{python3_sitelib}/setup.py
%endif
%py3_compile %{buildroot}%{python3_sitelib}/

%find_lang %{name}

sed -i 's|/usr/bin/env bash|/usr/bin/bash|g' %{buildroot}%{_bindir}/*
sed -i 's|/usr/bin/env python3|/usr/bin/python3|g' %{buildroot}%{_prefix}/lib/%{name}/mate-tweak-helper

%fdupes %{buildroot}

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_bindir}/marco-*
%{_prefix}/lib/%{name}/
%{python3_sitelib}/%{_name}-*
%if 0%{?suse_version} > 1500
%pycache_only %{python3_sitelib}/__pycache__
%endif
%{_datadir}/applications/%{name}.desktop
%{_datadir}/applications/marco-*.desktop
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_mandir}/man?/*-no-composite.?%{?ext_man}
%{_mandir}/man?/marco-glx.?%{?ext_man}
%{_mandir}/man?/marco-xr_glx_hybrid.?%{?ext_man}
%{_mandir}/man?/marco-xrender.?%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Thu Nov 28 2024 Richard Rahl <rrahl0@opensuse.org>
- fix Leap 15.6 build by excluding some of the build process
- fix rpmlint issues (shebang, duplicates, forgotten runtime dep)
* Mon Mar 27 2023 Alexei Sorokin <sor.alexei@meowr.ru>
- Update version to 22.10.0:
  * Correct typo "Macro" -> "Marco" in man pages.
  * Ignore case for Firefox.
- Switch to python-rpm-macros.
* Thu Sep  8 2022 Hillwood Yang <hillwood@opensuse.org>
- Fix filelist
* Wed May 11 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 22.04.8
  * Sync translations.
  * Fix GLib-GIO-ERROR when 'org.mate.maximus' settings schema is not
  * Use predictable path for checking ayatana-indicator-application
    is installed
  * Replace compton support with picom
  * Update mate-tweak to use several personalities provided by marco-wrapper
  * Exposes Xrender, GLX and xr_glx_hybrid backends from picom.
  * Add a fallback marco-compton for users migrating from earlier
    versions of MATE Tweak.
  * Make picom window shadows more consistent with CSD windows
  * Make sure outgoing window managers and compositors are killed
  * Use 'ldd' to determine which compositor is enabled in Marco
  * Refactor detection of picom wrappers
  * Add migration fallback for marco-picom
  * Make mate-tweak compatible with all Yaru themes
  * Update mate-tweak.desktop to use tweaks-app icon
  * Be explicit when looking for libXpresent
  * Refactor replace_panel_layout() to make switching robust
  * Check if dock is running to determine if it needs starting
  * Refactor replace_panel_layout() to start/stop keyboard LED
  * Prevent the dock from being started if it is not running
  * Refactor replace_panel_layout() to make it more reliable.
* Wed Mar 31 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 21.04.3:
  * Drop MATE Dock requirement for Netbook layout.
  * When switching to/from Mutiny update the Plank configuration
    accordingly.
  * Make Mutiny layout available if Plank is available.
    + Mutiny no longer uses mate-dock-applet.
  * Mutiny no longer uses Maximus or left-aligned window controls.
  * Fallback to a sane default Plank theme when not using a known
    GTK theme.
  * When switching to Mutiny layout pick a suitable Plank theme
    (lp#1917740).
  * Keep Brisk menu label visible in the Mutiny layout.
* Thu Aug 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Sat Feb 22 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 20.04.0 (changes since 18.10.2):
  * Update to preserve custom preferences.
  * Add support for Indicator-datetime.
  * Add NoDisplay=true to all Indicator autostart files.
  * Remove checks for obsolete GNOME Main Menu.
  * Migrate to python3-distro and drop use of the deprecated
    "platform" module.
  * Remove a call to "mate-panel --replace".
  * Remove clear shadow.
    This seems to affect how some shadows are positioned, leading
    to a clear space between the window and its shadow.
  * Correctly initialise all notifications so they are sent from
    MATE Tweak.
  * Add support for setting window manager button layouts with and
    without the menu.
  * Detect new IndicatorAppmenu.
  * Correct literal string comparison.
  * Detect Brisk menu on Arch Linux and Manjaro.
  * Update translations.
- Rebase mate-tweak-use-matemenu.patch.
- Drop support for old openSUSE versions.
* Sat Nov  3 2018 sor.alexei@meowr.ru
- Update to version 18.10.2 (changes since 18.04.13):
  * Use Dash launcher in Cupertino.
  * Add support for Familiar layout.
  * Change Marco description.
  * The HUD is layout independent. Do not restrict access to layout
    based on HUD availability.
  * Handle new Netbook layout. Make sure mate-panel remains running
    when switching window-scaling-factor.
  * Save dock state when saving panel layouts.
  * Also remove dock hints if dock status for a custom layout has
    changed.
  * Add button to access font DPI tweaking.
  * Add --get-layout.
  * Remove special handling of show-applications in the menu-bar
    for Pantheon, since it no longer merges two menus together.
  * Update the logic guards around layout detection.
  * When changing a layout via the terminal do not update UI
    elements.
  * Allow keyboard focus on side panel.
  * Fix removing cache dir when resetting Compiz.
  * Correct the search path for the appmenu panel applet
    (lp#1796343).
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 18.04.13:
  * No changelog available.
* Wed Sep 27 2017 sor.alexei@meowr.ru
- Update to version 17.10.15:
  * No changelog available.
- Rebase mate-tweak-use-matemenu.patch.
- Only suggest mate-hud.
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 17.10.1 (changes since 17.04.0):
  * Add support for the Pantheon layout.
  * Make sure the menu is always shown with the Contemporary window
    decoration layout.
  * Switch window control locations according to layout selected.
  * Add checks for MATE AppMenu applet and remove TopMenu checks.
  * Refactor enable/disable dock (lp#1559457).
  * Update Compton defaults to eliminate artifacting and allows the
    screensaver to function (lp#1599331).
  * Reduce sleep between starting the WM and the compositor.
  * Add Button to Open CCSM if it is available.
  * Make Menu Bar configuration insensitive for Cupertino which now
    uses the Menu only.
  * Refactor logic to control behaviour as layouts are switched.
    Prevent tracebacks when kill processes.
    More robust checking for Indicators in a layout.
  * Enable/Disbale Global Menu when switch to/from Mutiny and
    Cupertino.
  * Update translations.
- Rebase mate-tweak-use-matemenu.patch.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 17.04.0:
  * Update translations.
* Fri Nov 25 2016 sor.alexei@meowr.ru
- Update to version 16.10.5:
  * Add a comment to appear in mate-menu.
  * Support Metacity 3.20+.
* Fri Jul 22 2016 sor.alexei@meowr.ru
- Add missing python3-setproctitle requirement.
* Wed Jul 13 2016 sor.alexei@meowr.ru
- Update to version 16.10.4:
  * Add support for MATE HUD.
* Tue Jul  5 2016 sor.alexei@meowr.ru
- Update to version 16.10.3:
  * No changelog available.
* Wed Jun  8 2016 sor.alexei@meowr.ru
- Update to version 16.10.0:
  * No changelog available.
- Rebase mate-tweak-use-matemenu.patch.
* Wed May  4 2016 sor.alexei@meowr.ru
- Add a missing python3-gobject-Gdk dependency.
* Thu Apr 28 2016 sor.alexei@meowr.ru
- Update to version 3.5.10:
  * Modified composited window manager .desktop files to add a
    phase delayed startup (lp#1553070).
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 3.5.9 (changes since 3.5.7):
  * Misplacement of indicators and other applets when switching
    panel layouts (lp#1557203).
  * Don't render double shadows in GTK+ client-side decorated
    applications when enabling the Compton compositor via
    MATE Tweak (lp#1558013).
  * Provide a warning before changing Window Manager (lp#1549081).
  * Don't let MATE Tweak move upward on changing of the window
    manager (lp#1549076).
  * Fix forced setting of the xcursor theme (lp#1563087).
  * Fix psutil.AccessDenied crash (lp#1562843).
  * Fix handling of "unknown" window managers (lp#1563037).
  * Fix ordering of notebook entries (lp#1564957).
  * Fix toggling of menu bar features (lp#1564959).
  * Add translations for de_CH, es_419, sco, and zh-Hans.
  * Update existing translations.
- Rebase mate-tweak-use-matemenu.patch.
* Fri Mar  4 2016 sor.alexei@meowr.ru
- Update to 3.5.7:
  * Fix checking available features.
  * Make window snapping option inactive when reduced resources is
    enabled (lp#1548001).
  * Support Synapse.
- Add runtime dependencies to BuildRequires to ensure they are
  available on the target.
* Mon Feb 22 2016 sor.alexei@meowr.ru
- Update to 3.5.6:
  * Add topmenu support.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 3.5.5:
  * Do not daemonise in compton, just background instead.
  * Add missing manpages.
* Fri Jan 22 2016 sor.alexei@meowr.ru
- Update to 3.5.4.
- Remove mate-tweak-no-dock-lacking-warnings.patch: fixed upstream.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Add missing python3-gobject and mate-panel dependencies.
- Add mate-tweak-no-dock-lacking-warnings.patch: do not show Python
  warnings if no dock is present.
* Tue Dec 15 2015 sor.alexei@meowr.ru
- Update to 3.5.3 (boo#959025).
* Thu Nov 12 2015 sor.alexei@meowr.ru
- Add mate-tweak-use-matemenu.patch.
* Tue Sep 29 2015 sor.alexei@meowr.ru
- Update to 3.5.2a:
  * Remove all deprecated GTK+ properties (deb#797033).
  * Fix switching to Metacity so the currently selected theme is
    retained. (lp#1500882).
  * Fix CTRL+C not closing MATE Tweak (lp#1500884).
  * Fix Plank not being retained when saving a custom theme
    (lp#1500885).
  * Make irrelevant UI element insensitive rather than hiding them
    (lp#1500886).
  * Fix leaving multiple volume applets enabled when switching
    panel layouts (lp#1500919).
* Thu Aug 27 2015 sor.alexei@meowr.ru
- Update to 3.5.2:
  * Fix Mutter support.
  * Fix panel backup.
* Thu Aug 13 2015 sor.alexei@meowr.ru
- Update to 3.5.1:
  * Make Python 3.x compatible.
  * Fix Metacity 3.16 support.
  * Make detection of mate-indicator-applet architecture independent.
  * Remove some deprecated properties.
  * Update default XDG xcursor when switching window managers.
  * Update translations.
- Switch to Python 3.x.
- Search for gobject-introspection dependencies.
* Wed Jul 22 2015 sor.alexei@meowr.ru
- Update to 3.5.0:
  * Save, dump and install supplemental panel configuration.
  * Install panel layouts.
  * Modify policy for saving layouts and disabling volume applet.
  * Add Metacity 3.16 support.
  * Change gtk-window-decorator theme.
  * Better undecorate switching.
  * Minor UI refactor.
  * Add windows behaviour.
  * Correct order of mate-panel --replace.
  * Correct padding for Panel Features.
  * Update translations.
* Fri Jun 26 2015 sor.alexei@meowr.ru
- Update to 3.4.9:
  * Custom panel layout support.
  * Add Netbook panel layout.
  * Rename Eleven panel layout to Cupertino; the default layout to GNOME2.
  * Completely reset the dconf tree when switching panel layouts.
  * Add support for multiple window managers.
  * Add notifications.
  * Fix exit when switching between Compiz and Marco.
  * Add Compiz Reset button.
  * Add Maximus configuration.
  * UI refactoring.
  * Update translations.
* Fri May  1 2015 sor.alexei@meowr.ru
- Update to 3.4.8:
  * Refine setting of Metacity theme.
  * Remove utility scripts.
  * Correct mate-tweak.desktop.
  * Fix homepage in setup.py.
  * Update translations.
* Wed Apr  1 2015 sor.alexei@meowr.ru
- Update to 3.4.7:
  * Update translations.
* Tue Mar 17 2015 sor.alexei@meowr.ru
- Initial package.
